@@ -998,8 +998,14 @@ namespace msXpSlibmass
 
 			for(int iter = firstIdx; iter < lastIdx; ++iter)
 			{
-				combine(*(massSpectra.at(iter)), mzStart, mzEnd);
-				++count;
+				if(!m_isOperationCancelled)
+				{
+					combine(*(massSpectra.at(iter)), mzStart, mzEnd);
+					++count;
+					emit counterSignal(1);
+				}
+				else
+					emit counterSignal(-1);
 			}
 
 			return count;
@@ -1586,8 +1592,8 @@ namespace msXpSlibmass
 			{
 				m_binningType = msXpS::BinningType::BINNING_TYPE_NONE;
 
-				qDebug() << __FILE__ << __LINE__
-					<< "Single spectrum list: no binning.";
+				//qDebug() << __FILE__ << __LINE__
+				//<< "Single spectrum list: no binning.";
 
 				return true;
 			}
@@ -1605,7 +1611,9 @@ namespace msXpSlibmass
 
 			// Check if the m_minMz value was set by the caller already or not. If
 			// not, quickly get it. Note that this can only work because the DataPoint
-			// instances in a MassSpectrum are sorted in increasing DataPoint.m_key.
+			// instances in a MassSpectrum are sorted in increasing DataPoint.m_key:
+			// we use MassSpectrum::first() to get the first DataPoint instance as the
+			// one that has the smallest m/z key value of all.
 
 			if(m_minMz == std::numeric_limits<double>::max())
 			{
@@ -1616,7 +1624,8 @@ namespace msXpSlibmass
 				}
 			}
 
-			// Same for m_maxMz value.
+			// Same for m_maxMz value, but using MassSpectrum::last() to get the last
+			// m/z value as the one that has the greatest m/z key value of all.
 			if(m_maxMz == std::numeric_limits<double>::min())
 			{
 				for(int iter = 0; iter < massSpectra.size(); ++iter)
@@ -1836,7 +1845,7 @@ namespace msXpSlibmass
 
 			if(m_binSizeType == msXpS::MassToleranceType::MASS_TOLERANCE_AMU)
 				m_decimalPlaces = msXpS::zeroDecimals(m_binSize) + 1;
-			if(m_binSizeType == msXpS::MassToleranceType::MASS_TOLERANCE_MZ)
+			else if(m_binSizeType == msXpS::MassToleranceType::MASS_TOLERANCE_MZ)
 				m_decimalPlaces = msXpS::zeroDecimals(m_binSize) + 1;
 			else if(m_binSizeType == msXpS::MassToleranceType::MASS_TOLERANCE_PPM)
 				m_decimalPlaces = msXpS::zeroDecimals(msXpS::ppm(m_minMz, m_binSize)) + 1;
@@ -1857,12 +1866,12 @@ namespace msXpSlibmass
 			double firstMz = ceil((m_minMz * pow(10, m_decimalPlaces)) - 0.49) / pow(10, m_decimalPlaces);
 			double lastMz = ceil((m_maxMz * pow(10, m_decimalPlaces)) - 0.49) / pow(10, m_decimalPlaces);
 
-			// That is the very first data point in *this spectrum.
-
 			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
 			//<< QString::asprintf("Very first data point: %.6f\n", firstMz)
 			//<< QString::asprintf("Very last data point to reach: %.6f\n", lastMz);
 
+			// That is the very first data point in *this spectrum.
+
 			append(new DataPoint(firstMz, 0));
 
 			// Store that very first value for later use in the loop.
@@ -1882,7 +1891,7 @@ namespace msXpSlibmass
 
 				if(m_binSizeType == msXpS::MassToleranceType::MASS_TOLERANCE_AMU)
 					currentMz = previousMzBin + m_binSize;
-				if(m_binSizeType == msXpS::MassToleranceType::MASS_TOLERANCE_MZ)
+				else if(m_binSizeType == msXpS::MassToleranceType::MASS_TOLERANCE_MZ)
 					currentMz = previousMzBin + m_binSize;
 				else if(m_binSizeType == msXpS::MassToleranceType::MASS_TOLERANCE_PPM)
 					currentMz = msXpS::addPpm(previousMzBin, m_binSize /* ppm */);
@@ -1990,13 +1999,15 @@ namespace msXpSlibmass
 		 The \p massSpectrum passed as parameter is analysed and used for crafting
 		 new DataPoint instances to populate this spectrum with.
 
-		 The first DataPoint instance is derived from the very first DataPoint
-		 instance in \p massSpectrum. Then the bins are calculated as the delta
-		 between two consecutive DataPoint instances in \p massSpectrum. New
-		 DataPoint instances are crafted with their key being the delta computed at
-		 each step. The value (the intensity) is set to zero.
+		 The first DataPoint instance in this MassSpectrum is derived from the \c
+		 m_minMz. The subsequent data points are derived by incrementing that
+		 m_minMz value by the m/z steps (bins) as calculated by looking into \p
+		 massSpectrum. And so on.  The size of \c this MassSpectrum will thus have
+		 the same size as massSpectrum. Note that \c m_maxMz is not used in this
+		 computation.
 
-*/
+		 The value (the intensity) is set to zero.
+		 */
 	int
 		MassSpectrum::populateSpectrumWithDataBasedBins(const MassSpectrum &massSpectrum)
 		{
@@ -2014,7 +2025,11 @@ namespace msXpSlibmass
 			double localMz = m_minMz;
 			if(m_decimalPlaces != -1)
 				localMz = ceil((localMz * pow(10, m_decimalPlaces)) - 0.49) / pow(10, m_decimalPlaces);
+
+			// This is the very first data point where no actual step computation is
+			// needed.
 			append(new DataPoint(localMz, 0));
+
 			double previousMzBin = localMz;
 
 			double prevMz = massSpectrum.first()->m_key;
@@ -2217,6 +2232,12 @@ namespace msXpSlibmass
 		}
 
 
+	void
+		MassSpectrum::cancelOperation()
+		{
+			m_isOperationCancelled = true;
+		}
+
 } // namespace msXpSlibmass
 
 
