@@ -75,6 +75,8 @@ namespace msXpSlibmass
 		:
 			public Trace
 	{
+		Q_OBJECT
+
 		friend class MassSpectrumJs;
 
 		private:
@@ -112,6 +114,8 @@ namespace msXpSlibmass
 		//! Value by which the mass spectra need to be shifted when aligned.
 		double m_mzShift = 0;
 
+		bool m_isOperationCancelled = false;
+
 		public:
 
 		MassSpectrum();
@@ -215,6 +219,11 @@ namespace msXpSlibmass
 		double tic();
 		double tic(double mzStart, double mzEnd);
 		static double tic(const QList<MassSpectrum *> &massSpectra);
+
+		void cancelOperation();
+
+		signals:
+		void counterSignal(int count);
 	};
 
 } // namespace msXpSlibmass
