@@ -62,9 +62,11 @@ namespace msXpSlibmass
 		of mass spectra, for example).
 
 */
-	class Trace : public QList<DataPoint *>
+	class Trace : public QObject, public QList<DataPoint *>
 	{
-		friend class TraceJs;
+		Q_OBJECT
+
+			friend class TraceJs;
 
 		protected:
 
@@ -172,7 +174,7 @@ namespace msXpSlibmass
 		void toVectors(QVector<double> *keyVector, QVector<double> *valVector) const;
 		void toMap(QMap<double, double> *map) const;
 
-		QString *asText(int startIndex, int endIndex);
+		QString asText(int startIndex = -1, int endIndex = -1);
 
 		bool exportToFile(const QString &fileName);
 	};
