@@ -1,34 +1,35 @@
-/*  BEGIN software license
+/* BEGIN software license
  *
- *  msXpertSuite - mass spectrometry software suite
- *  -----------------------------------------------
- *  Copyright(C) 2009, 2017 Filippo Rusconi
+ * msXpertSuite - mass spectrometry software suite
+ * -----------------------------------------------
+ * Copyright(C) 2009,...,2018 Filippo Rusconi
  *
- *  http://www.msxpertsuite.org
+ * http://www.msxpertsuite.org
  *
- *  This file is part of the msXpertSuite project.
+ * This file is part of the msXpertSuite project.
  *
- *  The msXpertSuite project is the successor of the massXpert project. This
- *  project now includes various independent modules:
- *  
- *  - massXpert, model polymer chemistries and simulate mass spectrometric data;
- *  - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
+ * The msXpertSuite project is the successor of the massXpert project. This
+ * project now includes various independent modules:
  *
- *  This program is free software: you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation, either version 3 of the License, or
- *  (at your option) any later version.
+ * - massXpert, model polymer chemistries and simulate mass spectrometric data;
+ * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
  * END software license
-*/
+ */
+
 
 
 
@@ -46,11 +47,11 @@
 namespace msXpSmassXpert
 {
 
-	void 
+	void
 		SequenceEditorGraphicsView::keyPressEvent(QKeyEvent *event)
 		{
 			int keyCode = event->key();
-			QString text = event->text();  
+			QString text = event->text();
 			Qt::KeyboardModifiers modifiers = event->modifiers();
 
 
@@ -192,7 +193,7 @@ namespace msXpSmassXpert
 		}
 
 
-	void 
+	void
 		SequenceEditorGraphicsView::keyReleaseEvent(QKeyEvent *event)
 		{
 			//  qDebug() << "keyReleaseEvent";
@@ -215,7 +216,7 @@ namespace msXpSmassXpert
 		}
 
 
-	void 
+	void
 		SequenceEditorGraphicsView::keyPressEventKeyEscape(QKeyEvent *event)
 		{
 			mpa_monomerCodeEvaluator->escapeKey();
@@ -224,7 +225,7 @@ namespace msXpSmassXpert
 		}
 
 
-	void 
+	void
 		SequenceEditorGraphicsView::keyPressEventKeyReturn(QKeyEvent *event)
 		{
 			mpa_monomerCodeEvaluator->reportCompletions();
@@ -233,7 +234,7 @@ namespace msXpSmassXpert
 		}
 
 
-	void 
+	void
 		SequenceEditorGraphicsView::keyPressEventKeyBackspace(QKeyEvent *event)
 		{
 			QScrollBar *vScrollBar = verticalScrollBar();
@@ -283,7 +284,7 @@ namespace msXpSmassXpert
 				// 		<< "m_selectionFirstPoint" << m_selectionFirstPoint
 				// 		<< "m_selectionSecondPoint" << m_selectionSecondPoint;
 
-				return event->accept();;
+				return event->accept();
 			}
 
 			if (m_lastClickedVignette <= 0)
@@ -314,7 +315,7 @@ namespace msXpSmassXpert
 		}
 
 
-	void 
+	void
 		SequenceEditorGraphicsView::keyPressEventKeyDelete(QKeyEvent *event)
 		{
 			CoordinateList coordList;
@@ -348,7 +349,7 @@ namespace msXpSmassXpert
 				QPointF pointF = vignetteLocation(m_lastClickedVignette);
 				centerOn(pointF);
 
-				return event->accept();;
+				return event->accept();
 			}
 
 			if (m_lastClickedVignette >= mp_polymer->size())
@@ -365,7 +366,7 @@ namespace msXpSmassXpert
 		}
 
 
-	void 
+	void
 		SequenceEditorGraphicsView::keyPressEventAlpha(QKeyEvent *event)
 		{
 			//   qDebug() << "Entering keyPressEventAlpha with text:"
