@@ -118,13 +118,28 @@ namespace msXpSmineXpert
 		Q_INVOKABLE void jsSetMzIntegrationParams();
 		Q_INVOKABLE QScriptValue jsMzIntegrationParams() const;
 
-		Q_INVOKABLE void integrateToMz(double dtRangeStart, double dtRangeEnd,
+		void integrateToMz(double dtRangeStart, double dtRangeEnd,
 				double mzRangeStart, double mzRangeEnd);
-		Q_INVOKABLE void integrateToDt(double dtRangeStart, double dtRangeEnd,
+
+		Q_INVOKABLE void jsIntegrateToMz(double dtRangeStart, double dtRangeEnd,
 				double mzRangeStart, double mzRangeEnd);
-		Q_INVOKABLE void integrateToRt(double dtRangeStart, double dtRangeEnd,
+
+		void integrateToDt(double dtRangeStart, double dtRangeEnd,
 				double mzRangeStart, double mzRangeEnd);
-		Q_INVOKABLE void integrateToTicIntensity(double dtRangeStart, double dtRangeEnd,
+
+		Q_INVOKABLE void jsIntegrateToDt(double dtRangeStart, double dtRangeEnd,
+				double mzRangeStart, double mzRangeEnd);
+
+		void integrateToRt(double dtRangeStart, double dtRangeEnd,
+				double mzRangeStart, double mzRangeEnd);
+
+		Q_INVOKABLE void jsIntegrateToRt(double dtRangeStart, double dtRangeEnd,
+				double mzRangeStart, double mzRangeEnd);
+
+		void integrateToTicIntensity(double dtRangeStart, double dtRangeEnd,
+				double mzRangeStart, double mzRangeEnd);
+
+		Q_INVOKABLE double jsIntegrateToTicIntensity(double dtRangeStart, double dtRangeEnd,
 				double mzRangeStart, double mzRangeEnd);
 
 		Q_INVOKABLE void transposeAxes();
@@ -133,17 +148,23 @@ namespace msXpSmineXpert
 signals:
 		void recordAnalysisStanza(QString stanza, const QColor &color = QColor());
 
-		void newTicChromatogram(const MassSpecDataSet *massSpecDataSet,
-				const QString &msg, const History &history, QColor color);
-
 		void newMassSpectrum(const MassSpecDataSet *massSpecDataSet,
 				const QString &, const History &history, QColor color);
 
+		void jsNewMassSpectrum(const MassSpecDataSet *massSpecDataSet,
+				const QString &, const History &history, QColor color);
+
 		void newDriftSpectrum(const MassSpecDataSet *massSpecDataSet,
 				const QString &msg, const History &history, QColor color);
 
+		void jsNewDriftSpectrum(const MassSpecDataSet *massSpecDataSet,
+				const QString &msg, const History &history, QColor color);
+
 		void ticIntensitySignal(const MassSpecDataSet *massSpecDataSet,
 				const QString &msg, const History &history);
+
+		// No newTicChromatogram signal here because that signal is coded in
+		// AbstractMultiPlotWidget, since it is emitted from all derived classes.
 	};
 
 
