@@ -1,37 +1,38 @@
-/*  BEGIN software license
+/* BEGIN software license
  *
- *  msXpertSuite - mass spectrometry software suite
- *  -----------------------------------------------
- *  Copyright(C) 2009, 2017 Filippo Rusconi
+ * msXpertSuite - mass spectrometry software suite
+ * -----------------------------------------------
+ * Copyright(C) 2009,...,2018 Filippo Rusconi
  *
- *  http://www.msxpertsuite.org
+ * http://www.msxpertsuite.org
  *
- *  This file is part of the msXpertSuite project.
+ * This file is part of the msXpertSuite project.
  *
- *  The msXpertSuite project is the successor of the massXpert project. This
- *  project now includes various independent modules:
- *  
- *  - massXpert, model polymer chemistries and simulate mass spectrometric data;
- *  - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
+ * The msXpertSuite project is the successor of the massXpert project. This
+ * project now includes various independent modules:
  *
- *  This program is free software: you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation, either version 3 of the License, or
- *  (at your option) any later version.
+ * - massXpert, model polymer chemistries and simulate mass spectrometric data;
+ * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
  * END software license
  */
 
 
 
+
 /////////////////////// Qt includes
 #include <QLineEdit>
 
@@ -58,8 +59,6 @@ namespace msXpSmineXpert
 		// set the app name along with the title.
 		setWindowTitle(QString("%1 - Console").arg(m_applicationName));
 		readSettings();
-
-		show();
 	}
 
 
@@ -86,6 +85,7 @@ namespace msXpSmineXpert
 			settings.beginGroup("ConsoleWnd");
 			settings.setValue("geometry", saveGeometry());
 			settings.setValue("windowState", saveState());
+			settings.setValue("visible", isVisible());
 			settings.endGroup();
 		}
 
@@ -98,6 +98,10 @@ namespace msXpSmineXpert
 			settings.beginGroup("ConsoleWnd");
 			restoreGeometry(settings.value("geometry").toByteArray());
 			restoreState(settings.value("windowState").toByteArray());
+
+			bool wasVisible = settings.value("visible").toBool();
+			setVisible(wasVisible);
+
 			settings.endGroup();
 		}
 
