@@ -1323,7 +1323,7 @@ namespace msXpSmineXpert
 							// window, and
 							// that, with the proper color.
 
-							label = QString("(%1,%2)\n")
+							label = QString("DT(%1,%2)\n")
 								.arg(m_lastMousedPlotPoint.x())
 								.arg(m_lastMousedPlotPoint.y());
 
@@ -1353,7 +1353,7 @@ namespace msXpSmineXpert
 					// We are in a plot widget that is a single-graph plot widget, the
 					// situation is easier:
 
-					label = QString("(%1,%2)\n")
+					label = QString("DT(%1,%2)\n")
 						.arg(m_lastMousedPlotPoint.x())
 						.arg(m_lastMousedPlotPoint.y());
 
