@@ -82,9 +82,14 @@ namespace msXpSmineXpert
 			Q_INVOKABLE void jsSetMzIntegrationParams();
 			Q_INVOKABLE QScriptValue jsMzIntegrationParams() const;
 
-			Q_INVOKABLE void integrateToMz(double lower = qSNaN(), double upper = qSNaN());
-			Q_INVOKABLE void integrateToRt(double lower = qSNaN(), double upper = qSNaN());
-			Q_INVOKABLE void integrateToTicIntensity(double lower = qSNaN(), double upper = qSNaN());
+			void integrateToMz(double lower = qSNaN(), double upper = qSNaN());
+			Q_INVOKABLE void jsIntegrateToMz(double lower = qSNaN(), double upper = qSNaN());
+
+			void integrateToRt(double lower = qSNaN(), double upper = qSNaN());
+			Q_INVOKABLE void jsIntegrateToRt(double lower = qSNaN(), double upper = qSNaN());
+
+			void integrateToTicIntensity(double lower = qSNaN(), double upper = qSNaN());
+			Q_INVOKABLE double jsIntegrateToTicIntensity(double lower = qSNaN(), double upper = qSNaN());
 
 			Q_INVOKABLE void newPlot();
 
@@ -94,9 +99,15 @@ signals:
 			void newMassSpectrum(const MassSpecDataSet *massSpecDataSet,
 					const QString &msg, const History &history, QColor color);
 
+			void jsNewMassSpectrum(const MassSpecDataSet *massSpecDataSet,
+					const QString &msg, const History &history, QColor color);
+
 			void newTicChromatogram(const MassSpecDataSet *massSpecDataSet,
 					const QString &msg, const History &history, QColor color);
 
+			void jsNewTicChromatogram(const MassSpecDataSet *massSpecDataSet,
+					const QString &msg, const History &history, QColor color);
+
 			void ticIntensitySignal(const MassSpecDataSet *massSpecDataSet,
 					const QString &msg, const History &history);
 	};
