@@ -572,25 +572,6 @@ namespace msXpSmineXpert
 		}
 
 
-	/*/js/
-	 * MainWindow.createMassSpectrumFromClipboard()
-	 *
-	 * Create a new mass spectrum from data in the clipboard. The data in the
-	 * clipboard need to be under the format of <number><separator><number>,
-	 * <separator> being any non-numerical and non-'.' character. The first
-	 * <number> is the m/z and the second <number> is the intensity.
-	 *
-	 * Upon completing the parsing of the textual data in the clipboard, a pseudo
-	 * TIC chromatogram is created that needs to be integrated to a mass spectrum
-	 * using:
-	 *
-	 * lastTicChromPlotWidget.integrateToMz();
-	 *
-	 * Ex:
-	 * mainWindow.createMassSpectrumFromClipboard();
-	 * lastTicChromPlotWidget.integrateToMz();
-	 */
-
 	//! Create a mass spectrum starting from data in the clipboard.
 	void
 		MainWindow::createMassSpectrumFromClipboard()
@@ -679,12 +660,50 @@ namespace msXpSmineXpert
 			statusBarMessage("Calculating the TIC chromatogram...");
 			logConsoleMessage("Calculating the TIC chromatogram...\n");
 
-			mp_ticChromWnd->initialTic(p_massSpecDataSet, *useColor);
+			if(m_isScriptedOperation)
+			{
+				// This is a non-QThread-based version of the function
+				mp_ticChromWnd->jsInitialTic(p_massSpecDataSet, *useColor);
+			}
+			else
+			{
+				// This is a QThread-based version of the function
+				mp_ticChromWnd->initialTic(p_massSpecDataSet, *useColor);
+			}
 
 			// The initialTic function from TicChromWnd will signal
 			// "initialTicDoneSignal" to finalize the operation.
 		}
 
+
+	/*/js/
+	 * MainWindow.jsCreateMassSpectrumFromClipboard()
+	 *
+	 * Create a new mass spectrum from data in the clipboard. The data in the
+	 * clipboard need to be under the format of <number><separator><number>,
+	 * <separator> being any non-numerical and non-'.' character. The first
+	 * <number> is the m/z and the second <number> is the intensity.
+	 *
+	 * Upon completing the parsing of the textual data in the clipboard, a pseudo
+	 * TIC chromatogram is created that needs to be integrated to a mass spectrum
+	 * using:
+	 *
+	 * lastTicChromPlotWidget.integrateToMz();
+	 *
+	 * Ex:
+	 * mainWindow.createMassSpectrumFromClipboard();
+	 * lastTicChromPlotWidget.integrateToMz();
+	 */
+	void
+		MainWindow::jsCreateMassSpectrumFromClipboard()
+		{
+			m_isScriptedOperation = true;
+			createMassSpectrumFromClipboard();
+			m_isScriptedOperation = false;
+		}
+
+
+	//! Slot that handles the results after the initialTic function has performed its computation
 	void
 		MainWindow::initialTicDone(AbstractPlotWidget *widget,
 				const MassSpecDataSet *massSpecDataSet, QColor color)
@@ -764,7 +783,16 @@ namespace msXpSmineXpert
 				//<< "with massSpecDataSet:" << massSpecDataSet
 				//<< "and filename:" << massSpecDataSet->fileName();
 
-				mp_colorMapWnd->initialColorMap(massSpecDataSet, widget, color);
+				if(m_isScriptedOperation)
+				{
+					// This is a non-QThread-based version of the function
+					mp_colorMapWnd->jsInitialColorMap(massSpecDataSet, widget, color);
+				}
+				else
+				{
+					// This is a QThread-based version of the function
+					mp_colorMapWnd->initialColorMap(massSpecDataSet, widget, color);
+				}
 
 				// The initialColorMap function from ColorMapWnd will signal
 				// initialColorMapDone to finalize the operation.
@@ -833,25 +861,6 @@ namespace msXpSmineXpert
 			// data set. Otherwise it does not make sense.
 		}
 
-
-	/*/js/
-	 * MainWindow.openMassSpectrometryFile(fileName, streamed)
-	 *
-	 * Load mass spectrometry data from fileName.
-	 *
-	 * fileName: <String> holding the mass spectrometry data file name
-	 * streamed: <Boolean> telling if the loading should be in streamed mode.
-	 *
-	 * Ex:
-	 * mainWindow.openMassSpectrometryFile("/tmp/20161027-cgb-wt-mobility.db", true);
-	 *
-	 * reads the data in the file in streamed mode.
-	 *
-	 * mainWindow.openMassSpectrometryFile("/tmp/20161027-cgb-wt-mobility.db", false);
-	 *
-	 * reads the data in the file in full mode.
-	 */
-
 	//! Open a mass spectrometry file.
 	/*!
 
@@ -937,15 +946,33 @@ namespace msXpSmineXpert
 		}
 
 
-
 	/*/js/
-	 * MainWindow.openMassSpectrometryFiles(fileNameList, streamed)
+	 * MainWindow.jsOpenMassSpectrometryFile(fileName, streamed)
 	 *
-	 * Load mass spectrometry data from all the files in the fileNameList.
+	 * Load mass spectrometry data from fileName.
 	 *
-	 * fileNameList: <Array> of <String> objects holding the mass spectrometry data file names
+	 * fileName: <String> holding the mass spectrometry data file name
 	 * streamed: <Boolean> telling if the loading should be in streamed mode.
+	 *
+	 * Ex:
+	 * mainWindow.jsOpenMassSpectrometryFile("/tmp/20161027-cgb-wt-mobility.db", true);
+	 *
+	 * reads the data in the file in streamed mode.
+	 *
+	 * mainWindow.jsOpenMassSpectrometryFile("/tmp/20161027-cgb-wt-mobility.db", false);
+	 *
+	 * reads the data in the file in full mode.
 	 */
+	void
+		MainWindow::jsOpenMassSpectrometryFile(const QString &fileName, bool isStreamed)
+		{
+			m_isScriptedOperation = true;
+			openMassSpectrometryFile(fileName, isStreamed);
+			m_isScriptedOperation = false;
+
+			return;
+		}
+
 
 	//! Open the mass spectrometry files listed in \p fileList.
 	/*!
@@ -970,6 +997,24 @@ namespace msXpSmineXpert
 		}
 
 
+	/*/js/
+	 * MainWindow.jsOpenMassSpectrometryFiles(fileNameList, streamed)
+	 *
+	 * Load mass spectrometry data from all the files in the fileNameList.
+	 *
+	 * fileNameList: <Array> of <String> objects holding the mass spectrometry data file names
+	 * streamed: <Boolean> telling if the loading should be in streamed mode.
+	 */
+	void
+		MainWindow::jsOpenMassSpectrometryFiles(const QStringList &fileList,
+				bool isStreamed)
+		{
+			m_isScriptedOperation = true;
+			openMassSpectrometryFiles(fileList, isStreamed);
+			m_isScriptedOperation = false;
+		}
+
+
 	//! Open a mass spectrometry file in SQLite3 format.
 	/*!
 
@@ -2586,11 +2631,20 @@ namespace msXpSmineXpert
 					this,
 					&MainWindow::initialColorMapDone);
 
-			mp_ticChromWnd->initialTic(p_massSpecDataSet, *useColor);
-
 			statusBarMessage("Calculating the TIC chromatogram...");
 			logConsoleMessage("Calculating the TIC chromatogram...\n");
 
+			if(m_isScriptedOperation)
+			{
+				// This is a non-QThread-based version of the function
+				mp_ticChromWnd->jsInitialTic(p_massSpecDataSet, *useColor);
+			}
+			else
+			{
+				// This is a QThread-based version of the function
+				mp_ticChromWnd->initialTic(p_massSpecDataSet, *useColor);
+			}
+
 			// The initialTic function from TicChromWnd will emit the
 			// initialTicDoneSignal. From that signal slot function, the process of
 			// calculating the color map is started.
