@@ -122,9 +122,14 @@ namespace msXpSmineXpert
 
 			void keyReleaseEvent(QKeyEvent *event) override;
 
-			Q_INVOKABLE void integrateToDt(double lower = qSNaN(), double upper = qSNaN());
-			Q_INVOKABLE void integrateToRt(double lower = qSNaN(), double upper = qSNaN());
-			Q_INVOKABLE void integrateToTicIntensity(double lower = qSNaN(), double upper = qSNaN());
+			void integrateToDt(double lower = qSNaN(), double upper = qSNaN());
+			Q_INVOKABLE void jsIntegrateToDt(double lower = qSNaN(), double upper = qSNaN());
+
+			void integrateToRt(double lower = qSNaN(), double upper = qSNaN());
+			Q_INVOKABLE void jsIntegrateToRt(double lower = qSNaN(), double upper = qSNaN());
+
+			void integrateToTicIntensity(double lower = qSNaN(), double upper = qSNaN());
+			Q_INVOKABLE double jsIntegrateToTicIntensity(double lower = qSNaN(), double upper = qSNaN());
 
 			Q_INVOKABLE msXpSlibmass::MassSpectrum massSpectrum(double lower = qSNaN(), double upper = qSNaN());
 
@@ -138,9 +143,15 @@ signals:
 			void newDriftSpectrum(const MassSpecDataSet *massSpecDataSet,
 					const QString &msg, const History &history, QColor color);
 
+			void jsNewDriftSpectrum(const MassSpecDataSet *massSpecDataSet,
+					const QString &msg, const History &history, QColor color);
+
 			void newTicChromatogram(const MassSpecDataSet *massSpecDataSet,
 					const QString &msg, const History &history, QColor color);
 
+			void jsNewTicChromatogram(const MassSpecDataSet *massSpecDataSet,
+					const QString &msg, const History &history, QColor color);
+
 			void ticIntensitySignal(const MassSpecDataSet *massSpecDataSet,
 					const QString &msg, const History &history);
 	};
