@@ -362,7 +362,6 @@ namespace msXpSmineXpert
 			thread->start();
 		}
 
-
 	void
 		MassSpecWnd::newMassSpectrumDone(MassDataIntegrator *integrator,
 				AbstractPlotWidget *senderPlotWidget, QColor color)
@@ -429,17 +428,35 @@ namespace msXpSmineXpert
 			// Make sure we get the signal requiring to redraw the background of the
 			// widget, depending on it being focused or not.
 
-			connect(this, &AbstractMultiPlotWnd::redrawPlotBackground, widget,
+			connect(this,
+					&AbstractMultiPlotWnd::redrawPlotBackground,
+					widget,
 					&AbstractPlotWidget::redrawPlotBackground);
 
-			connect(widget, &MassSpecPlotWidget::newDriftSpectrum,
-					mainWindow->mp_driftSpecWnd, &DriftSpecWnd::newDriftSpectrum);
+			connect(widget,
+					&MassSpecPlotWidget::newDriftSpectrum,
+					mainWindow->mp_driftSpecWnd,
+					&DriftSpecWnd::newDriftSpectrum);
 
-			connect(widget, &MassSpecPlotWidget::newTicChromatogram,
-					mainWindow->mp_ticChromWnd, &TicChromWnd::newTicChromatogram);
+			connect(widget,
+					&MassSpecPlotWidget::jsNewDriftSpectrum,
+					mainWindow->mp_driftSpecWnd,
+					&DriftSpecWnd::jsNewDriftSpectrum);
 
-			connect(widget, &MassSpecPlotWidget::ticIntensitySignal,
-					this, &MassSpecWnd::ticIntensity);
+			connect(widget,
+					&MassSpecPlotWidget::newTicChromatogram,
+					mainWindow->mp_ticChromWnd,
+					&TicChromWnd::newTicChromatogram);
+
+			connect(widget,
+					&MassSpecPlotWidget::jsNewTicChromatogram,
+					mainWindow->mp_ticChromWnd,
+					&TicChromWnd::jsNewTicChromatogram);
+
+			connect(widget,
+					&MassSpecPlotWidget::ticIntensitySignal,
+					this,
+					&MassSpecWnd::ticIntensity);
 
 			mainWindow->m_dataPlotWidgetRelationer.newRelation(
 					integrator->massSpecDataSet(), senderPlotWidget, widget,
@@ -450,6 +467,149 @@ namespace msXpSmineXpert
 		}
 
 
+	//! Integrate data to a mass spectrum.
+	/*!
+
+		\param massSpecDataSet pointer to the MassSpecDataSet where the mass data
+		are stored.
+
+		\param history History to account for the integration.
+
+		\param color to use to plot the graph of the new mass spectrum.
+
+*/
+	void
+		MassSpecWnd::jsNewMassSpectrum(const MassSpecDataSet *massSpecDataSet,
+				const QString &msg, History history, QColor color)
+		{
+			if(massSpecDataSet == Q_NULLPTR)
+				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
+
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+			//<< "m_wishedColor:" << color;
+
+			// Make sure the cancel button is visible.
+			mp_statusBarCancelPushButton->setVisible(true);
+
+			MassDataIntegrator integrator(massSpecDataSet, history);
+
+			connect(&integrator,
+					&MassDataIntegrator::updateFeedbackSignal,
+					this,
+					&AbstractMultiPlotWnd::updateFeedback);
+
+			connect(this,
+					&AbstractMultiPlotWnd::cancelOperationSignal,
+					&integrator,
+					&MassDataIntegrator::cancelOperation);
+
+			integrator.integrate();
+
+			//qDebug() << "At this point the integration is finished. Desetup the feedback.";
+
+			//De-setup the feedback.
+			QTimer::singleShot(2000, this, [=]()
+					{
+					updateFeedback("", -1, false /* setVisible */, LogType::LOG_TO_STATUS_BAR);
+					}
+					);
+
+			// Make sure the cancel button is hidden.
+			mp_statusBarCancelPushButton->setVisible(false);
+
+			// Create a text item to indicate the last history item.
+
+			QString historyItemText = history.newestHistoryItem()->asText(true /* brief */);
+
+			QString plotText = QString("%1\n%2 - %3 ")
+				.arg(massSpecDataSet->fileName())
+				.arg(m_desc)
+				.arg(historyItemText);
+
+			// Allocate the new plot widget in which the data are to be plot.
+
+			MassSpecPlotWidget *widget = static_cast<MassSpecPlotWidget *>(
+					addPlotWidget(integrator.keyVector(), integrator.valVector(),
+						plotText, color, massSpecDataSet));
+
+			// The history that we get as a parameter needs to be appended to the new
+			// widget's history so that we have a full account of the history.
+
+			widget->rhistory().copyHistory(history, true /*remove duplicates*/);
+
+			MainWindow *mainWindow = static_cast<MainWindow *>(parent());
+			mainWindow->logConsoleMessage(widget->history().asText(
+						"Plot widget history: \n", "End plot widget history:\n"));
+			// And now only the innermost ranges of the whole history.
+			mainWindow->logConsoleMessage(widget->history().innermostRangesAsText());
+
+			// The plot widget reacts to the Qt::Key_Delete key by calling a function
+			// that emits a set of signals, of which the destroyPlotWidget signal
+			// actually indirectly triggers the destruction of the plot widget. This
+			// signal is now connected to the main window where a function will call
+			// for the destruction of all the target plot widgets, that is all the
+			// plot widgets that were created as the result of an integration
+			// computation of the plot widget currently being destroyed.
+
+			connect(widget, &AbstractPlotWidget::destroyPlotWidget, mainWindow,
+					&MainWindow::destroyAlsoAllTargetPlotWidgets);
+
+			connect(widget, &AbstractPlotWidget::toggleMultiGraphSignal,
+					mainWindow, &MainWindow::toggleMultiGraph);
+
+			// Ensure that there is a connection between this plot widget and this
+			// containing window, such that if there is a requirement to replot, the
+			// widget gets the signal.
+
+			connect(this, &AbstractMultiPlotWnd::replotWithAxisRange, widget,
+					&AbstractPlotWidget::replotWithAxisRange);
+
+			// Make sure we get the signal requiring to redraw the background of the
+			// widget, depending on it being focused or not.
+
+			connect(this,
+					&AbstractMultiPlotWnd::redrawPlotBackground,
+					widget,
+					&AbstractPlotWidget::redrawPlotBackground);
+
+			connect(widget,
+					&MassSpecPlotWidget::newDriftSpectrum,
+					mainWindow->mp_driftSpecWnd,
+					&DriftSpecWnd::newDriftSpectrum);
+
+			connect(widget,
+					&MassSpecPlotWidget::jsNewDriftSpectrum,
+					mainWindow->mp_driftSpecWnd,
+					&DriftSpecWnd::newDriftSpectrum);
+
+			connect(widget,
+					&MassSpecPlotWidget::newTicChromatogram,
+					mainWindow->mp_ticChromWnd,
+					&TicChromWnd::newTicChromatogram);
+
+			connect(widget,
+					&MassSpecPlotWidget::jsNewTicChromatogram,
+					mainWindow->mp_ticChromWnd,
+					&TicChromWnd::jsNewTicChromatogram);
+
+			connect(widget,
+					&MassSpecPlotWidget::ticIntensitySignal,
+					this,
+					&MassSpecWnd::ticIntensity);
+
+			AbstractPlotWidget *senderPlotWidget =
+				dynamic_cast<AbstractPlotWidget *>(QObject::sender());
+
+			if(senderPlotWidget == Q_NULLPTR)
+				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
+
+			mainWindow->m_dataPlotWidgetRelationer.newRelation(
+					massSpecDataSet, senderPlotWidget, widget,
+					Q_NULLPTR /* open spectra dialog list widget item */);
+		}
+
+
+
 	void
 		MassSpecWnd::ticIntensity(const MassSpecDataSet *massSpecDataSet,
 				const QString &msg, History history)
@@ -504,8 +664,8 @@ namespace msXpSmineXpert
 					integrator,
 					&MassDataIntegrator::cancelOperation);
 
-			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-			//<< "current thread id:" << QThread::currentThreadId();
+			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+				<< "current thread id:" << QThread::currentThreadId();
 
 			thread->start();
 		}
