@@ -136,7 +136,7 @@ namespace msXpSmineXpert
 
 */
 	QListWidgetItem *
-		OpenSpectraDlg::addOpenSpectrum(MassSpecDataSet *dataSet, QColor color)
+		OpenSpectraDlg::addOpenSpectrum(const MassSpecDataSet *dataSet, QColor color)
 		{
 			if(dataSet == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
