@@ -94,7 +94,7 @@ namespace msXpSmineXpert
 			void writeSettings();
 			void readSettings();
 
-			QListWidgetItem *addOpenSpectrum(MassSpecDataSet *dataSet, QColor color);
+			QListWidgetItem *addOpenSpectrum(const MassSpecDataSet *dataSet, QColor color);
 			void actionComboBoxActivated(const QString &text);
 			void removeListWidgetItem(AbstractPlotWidget *widget);
 			bool isPlotWidgetSelected(AbstractPlotWidget *widget);
