@@ -41,6 +41,7 @@
 #include <QDebug>
 #include <QFileDialog>
 #include <QFile>
+#include <QScrollBar>
 
 
 ///////////////////////////// Local includes
@@ -1632,6 +1633,8 @@ namespace msXpSmineXpert
 			format.setForeground(QBrush(reqColor));
 			cursor.setCharFormat(format);
 			cursor.insertText(text);
+
+			m_ui.outTextEdit->verticalScrollBar()->setValue(m_ui.outTextEdit->verticalScrollBar()->maximum());
 		}
 
 
@@ -1685,6 +1688,9 @@ namespace msXpSmineXpert
 			//<< "logging history, after insertion of new item"
 			//<< ", item count:" << m_ui.historyListWidget->count()
 			//<< "; with last index set to that count:" << m_lastHistoryIndex;
+
+			// Make sure the last item is visible
+			m_ui.historyListWidget->setCurrentItem(item);
 		}
 
 
@@ -1753,14 +1759,18 @@ namespace msXpSmineXpert
 				logOutTextEdit(QString("%1%2").arg(m_commentPrefix).arg(comment), LogTextColor::Comment);
 
 			QString scriptElement;
-			QStringList scriptElements = script.split(QRegularExpression("(\\s*;\\s*\n)"), QString::SkipEmptyParts);
+
+			// First, split according to the ';', taking into account the potential //
+			// comment and newline.
+			QStringList scriptElements = script.split(QRegularExpression("(\\s*;\\s*(//.*)*\n?)"), QString::SkipEmptyParts);
 
 			bool scriptsFailed = false;
 
 			if(scriptElements.size() > 1)
 			{
 				qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-					<< "scriptElements size:" << scriptElements.size();
+					<< "scriptElements size:" << scriptElements.size()
+					<< "scriptElements:" << scriptElements;
 
 				for(int iter = 0; iter < scriptElements.size(); ++iter)
 				{
