@@ -315,7 +315,7 @@ namespace msXpSmineXpert
 					}
 					if(curChar == 'y')
 					{
-						stanza += "this is the drift count delta y";
+						stanza += "this is the TIC chrom count delta y";
 
 						prevChar = ' ';
 						continue;
@@ -327,7 +327,20 @@ namespace msXpSmineXpert
 						prevChar = ' ';
 						continue;
 					}
+					if(curChar == 's')
+					{
+						stanza += QString("%1").arg(m_keyRangeStart, 0, 'f', 3);
 
+						prevChar = ' ';
+						continue;
+					}
+					if(curChar == 'e')
+					{
+						stanza += QString("%1").arg(m_keyRangeEnd, 0, 'f', 3);
+
+						prevChar = ' ';
+						continue;
+					}
 					// At this point the '%' is not followed by any special character
 					// above, so we skip them both from the text. If the '%' is to be
 					// printed, then it needs to be escaped.
@@ -853,7 +866,7 @@ namespace msXpSmineXpert
 	 * lower, upper: retention time values limiting the integration. If no values
 	 * are provided, there is no limitation to the integration.
 	 *
-	 * The TIC intensity value is returned
+	 * This function creates a new plot widget to display the obtained results.
 	 */
 	void
 		TicChromPlotWidget::jsIntegrateToXic(double lower, double upper)
@@ -1208,7 +1221,7 @@ namespace msXpSmineXpert
 							// We can craft the label text to send to the console window, and
 							// that, with the proper color.
 
-							label = QString("(%1,%2)\n")
+							label = QString("RT(%1,%2)\n")
 								.arg(m_lastMousedPlotPoint.x())
 								.arg(m_lastMousedPlotPoint.y());
 
@@ -1238,7 +1251,7 @@ namespace msXpSmineXpert
 					// We are in a plot widget that is a single-graph plot widget, the
 					// situation is easier:
 
-					label = QString("(%1,%2)\n")
+					label = QString("RT(%1,%2)\n")
 						.arg(m_lastMousedPlotPoint.x())
 						.arg(m_lastMousedPlotPoint.y());
 
