@@ -84,13 +84,19 @@ namespace msXpSmineXpert
 			Q_INVOKABLE void jsSetMzIntegrationParams();
 			Q_INVOKABLE QScriptValue jsMzIntegrationParams() const;
 
-			Q_INVOKABLE void integrateToMz(double lower = qSNaN(), double upper = qSNaN());
-			Q_INVOKABLE void integrateToDt(double lower = qSNaN(), double upper = qSNaN());
-			Q_INVOKABLE void integrateToTicIntensity(double lower = qSNaN(), double upper = qSNaN());
+			void integrateToMz(double lower = qSNaN(), double upper = qSNaN());
+			Q_INVOKABLE void jsIntegrateToMz(double lower = qSNaN(), double upper = qSNaN());
 
-			Q_INVOKABLE void integrateToXic(double lower, double upper);
+			void integrateToDt(double lower = qSNaN(), double upper = qSNaN());
+			Q_INVOKABLE void jsIntegrateToDt(double lower = qSNaN(), double upper = qSNaN());
 
-			Q_INVOKABLE void statistics();
+			void integrateToTicIntensity(double lower = qSNaN(), double upper = qSNaN());
+			Q_INVOKABLE double jsIntegrateToTicIntensity(double lower = qSNaN(), double upper = qSNaN());
+
+			void integrateToXic(double lower, double upper);
+			Q_INVOKABLE void jsIntegrateToXic(double lower, double upper);
+
+			Q_INVOKABLE QString statistics();
 
 			Q_INVOKABLE void newPlot();
 
@@ -101,11 +107,20 @@ signals:
 			void newMassSpectrum(const MassSpecDataSet *massSpecDataSet,
 					const QString &msg, History history, QColor color);
 
+			void jsNewMassSpectrum(const MassSpecDataSet *massSpecDataSet,
+					const QString &msg, History history, QColor color);
+
 			void newDriftSpectrum(const MassSpecDataSet *massSpecDataSet,
 					const QString &msg, History history, QColor color);
 
+			void jsNewDriftSpectrum(const MassSpecDataSet *massSpecDataSet,
+					const QString &msg, History history, QColor color);
+
 			void ticIntensitySignal(const MassSpecDataSet *massSpecDataSet,
 					const QString &msg, const History &history);
+
+			// No newTicChromatogram signal here because that signal is coded in
+			// AbstractMultiPlotWidget, since it is emitted from all derived classes.
 	};
 
 
