@@ -109,10 +109,14 @@ namespace msXpSmineXpert
 					bool isMultiGraph = false) override;
 
 			void initialTic(const MassSpecDataSet *massSpecDataSet, QColor color = Qt::black);
+			void jsInitialTic(const MassSpecDataSet *massSpecDataSet, QColor color = Qt::black);
 
 			void newTicChromatogram(const MassSpecDataSet *massSpecDataSet,
 					const QString &msg, History history, QColor color);
 
+			void jsNewTicChromatogram(const MassSpecDataSet *massSpecDataSet,
+					const QString &msg, History history, QColor color);
+
 			void ticIntensity(const MassSpecDataSet *massSpecDataSet,
 					const QString &msg, History history);
 
