@@ -77,9 +77,9 @@ namespace msXpSmineXpert
 		:
 			mp_massSpecDataSet{massSpecDataSet}
 	{
-		qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-			<< "Allocating new integrator:" << this
-			<< "with mp_massSpecDataSet{massSpecDataSet}:" << mp_massSpecDataSet;
+		//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+		//<< "Allocating new integrator:" << this
+		//<< "with mp_massSpecDataSet{massSpecDataSet}:" << mp_massSpecDataSet;
 	}
 
 
@@ -99,17 +99,17 @@ namespace msXpSmineXpert
 			mp_massSpecDataSet{massSpecDataSet},
 		m_history{history}
 	{
-		qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-			<< "Allocating new integrator:" << this
-			<< "with mp_massSpecDataSet{massSpecDataSet}:" << mp_massSpecDataSet
-			<< "and history:" << m_history.asText();
+		//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+		//<< "Allocating new integrator:" << this
+		//<< "with mp_massSpecDataSet{massSpecDataSet}:" << mp_massSpecDataSet
+		//<< "and history:" << m_history.asText();
 	}
 
 
 	//! Destroy \c this MassDataIntegrator instance.
 	MassDataIntegrator::~MassDataIntegrator()
 	{
-		qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
+		//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
 	}
 
 	void
@@ -268,8 +268,8 @@ namespace msXpSmineXpert
 	void
 		MassDataIntegrator::initialTic()
 		{
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "() - enter"
-				<< "with this:" << this << " - current thread id:" << QThread::currentThreadId();
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "() - enter"
+			//<< "with this:" << this << " - current thread id:" << QThread::currentThreadId();
 
 			if(mp_massSpecDataSet->isStreamed())
 				return streamInitialTic();
@@ -303,7 +303,7 @@ namespace msXpSmineXpert
 						"Program aborted.",
 						__FILE__, __LINE__, __FUNCTION__);
 
-			// FIXME Be careful that integrateToRt() emits resultsReadySignal().
+			// Be careful that integrateToRt() emits resultsReadySignal().
 			// emit resultsReadySignal();
 		}
 
@@ -343,7 +343,7 @@ namespace msXpSmineXpert
 	void
 		MassDataIntegrator::fillInDtMzHash()
 		{
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
 
 			// We'll need this hash for storing the correspondence between any given dt
 			// value and the corresponding combination spectrum obtained by combining
@@ -618,8 +618,8 @@ namespace msXpSmineXpert
 	bool
 		MassDataIntegrator::integrateToRt()
 		{
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-				"executing from thread id:" << QThread::currentThreadId();
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+			//"executing from thread id:" << QThread::currentThreadId();
 
 			m_keyVector.clear();
 			if(mp_massSpecDataSet->isStreamed())
