@@ -39,7 +39,7 @@
 #include <QRegularExpression>
 #include <QDebug>
 #include <QVector>
-
+#include <QCoreApplication>
 
 ////////////////////////////// local includes
 #include <minexpert/nongui/MassSpecDataFileLoaderDx.hpp>
@@ -374,6 +374,8 @@ namespace msXpSmineXpert
 
 			while(!file.atEnd())
 			{
+				QCoreApplication::processEvents();
+
 				if(m_isOperationCancelled)
 					break;
 
@@ -564,8 +566,8 @@ namespace msXpSmineXpert
 
 				QString msg = QString("Parsed spectrum number %1\n").arg(spectraRead);
 
-				emit dataLoadMessageSignal(msg, LOG_TO_BOTH);
-				emit dataLoadProgressSignal(spectraRead);
+				emit updateFeedbackSignal(msg, spectraRead, true /* setVisible */,
+						LogType::LOG_TO_BOTH);
 			}
 
 			// We may be here because the operation was cancelled. Of course, in that
@@ -679,7 +681,7 @@ namespace msXpSmineXpert
 
 			QString msgSkeleton = "Computing streamed m/z integration";
 
-			emit setupFeedbackSignal(msgSkeleton, 0, 0, -1, LogType::LOG_TO_BOTH);
+			emit updateFeedbackSignal(msgSkeleton, 0, true /* setVisible */, LogType::LOG_TO_BOTH);
 
 			QFile file(m_fileName);
 
@@ -890,7 +892,8 @@ namespace msXpSmineXpert
 					QString msg =
 						QString(" -- spectrum number %1\n").arg(spectraRead);
 
-					emit updateFeedbackSignal(msgSkeleton + msg, -1, LogType::LOG_TO_STATUS_BAR);
+					emit updateFeedbackSignal(msgSkeleton + msg, -1,
+							true /* setVisible */, LogType::LOG_TO_STATUS_BAR);
 
 					//qDebug() << __FILE__ << __LINE__ << msg;
 				}
