@@ -157,8 +157,6 @@ namespace msXpSmineXpert
 			m_driftTimeMax = -1;
 			m_driftTimeStep = -1;
 			m_prevDriftTime = -1;
-			m_curDriftBin = 0;
-			m_driftBinCount = 0;
 		}
 
 
@@ -208,32 +206,24 @@ namespace msXpSmineXpert
 			{
 				// qDebug() << __FILE__ << __LINE__
 				// << "Spectrum index: " << m_spectrumIndex
-				// << "with m_curDriftTime: " << m_curDriftTime
-				// << "and m_curDriftBin: " << m_curDriftBin;
+				// << "with m_curDriftTime: " << m_curDriftTime;
 
-				if(m_curDriftTime == m_driftTimeMin)
+				// When the software was initially developed the reference data
+				// material was from Waters Synapt HDMS G2 instrument, and the drift
+				// times were extremely reproducible. Thus we could write the following
+				// if statement:
+				// if(m_curDriftTime == m_driftTimeMin)
+				//
+				// When I started looking at Agilent data, I discovered that the very
+				// first drift time of cycle 1 and cycle 2 were not identical. So I had
+				// to change the if statement to this:
+				if(m_curDriftTime <= m_driftTimeMin)
 				{
 					// We are starting a new drift cycle because we are not
 					// at the 0-index iteration (specIndex != 0) and the
 					// drift time is nonetheless the same as the one on the
 					// first iteration.
 
-					// We thus can store the drift bin count, that is the number
-					// of
-					// drift bins
-					// in a mobility cycle. This count is set to the current
-					// spectrum
-					// index
-					// that will match the number of spectra before this one that
-					// initiates a
-					// new drift cycle.
-					m_driftBinCount = m_spectrumIndex;
-					m_curDriftBin = 1;
-
-					// qDebug() << __FILE__ << __LINE__
-					// << "Encountered a new instance of the m_driftTimeMin"
-					// << "Set m_curDriftBin to: " << m_curDriftBin;
-
 					// And also set the max drift time, since we stored that value
 					// during the previous iteration.
 					m_driftTimeMax = m_prevDriftTime;
@@ -247,19 +237,6 @@ namespace msXpSmineXpert
 					//FIXME
 					//emit dataLoadMessageSignal(
 					//"The data are for a mobility experiment.", LOG_TO_BOTH);
-
-					if(m_driftBinCount == 0)
-					{
-						qFatal("Fatal error at %s@%d. The value of driftBinCount "
-								"is 0. "
-								"Fatal error. Program aborted.",
-								__FILE__, __LINE__);
-					}
-					else
-					{
-						// qDebug() << __FILE__ << __LINE__
-						// << "The driftBinCount is " << m_driftBinCount;
-					}
 				}
 			}
 			// Store the drift time value for the next round, if we need it.
@@ -270,7 +247,6 @@ namespace msXpSmineXpert
 			m_msFileMetaData.setDoubleItem("driftTimeMin", m_driftTimeMin);
 			m_msFileMetaData.setDoubleItem("driftTimeMax", m_driftTimeMax);
 			m_msFileMetaData.setDoubleItem("driftTimeStep", m_driftTimeStep);
-			m_msFileMetaData.setIntItem("driftBinCount", m_driftBinCount);
 		}
 
 
@@ -494,10 +470,6 @@ namespace msXpSmineXpert
 				return -1;
 			}
 
-			// A new spectrum is necessarily a new drift bin (if data are for a
-			// ion mobility experiment.
-			m_curDriftBin++;
-
 			// We use this variable to check for NaN drift time values (Waters Synapt
 			// files do have odd mzML elements.
 			bool wasNanOrInf = false;
@@ -642,19 +614,6 @@ namespace msXpSmineXpert
 
 			if(!m_isMobilityExperiment)
 				seedMobilityData();
-			else
-			{
-				// m_driftBinCount is set by the seedMobilityData()
-
-				if(m_curDriftBin > m_driftBinCount)
-				{
-					m_curDriftBin = 1;
-				}
-
-				// qDebug() << __FILE__ << __LINE__
-				//<< "spectrum index: " << m_spectrumIndex
-				//<< "current drift bin: " << m_curDriftBin;
-			}
 
 			// Finally report the results:
 			*p_spectrumPtr = spectrumPtr;
@@ -801,7 +760,6 @@ namespace msXpSmineXpert
 				{
 					// qDebug() << __FILE__ << __LINE__
 					// << "This file is from a mobility experiment."
-					// << "m_curDriftBin: " << m_curDriftBin
 					// << "m_curDriftTime:" << m_curDriftTime;
 
 					// Let's see if for the current drift time, a spectrum
@@ -938,7 +896,6 @@ namespace msXpSmineXpert
 				{
 					// qDebug() << __FILE__ << __LINE__
 					// << "This file is from a mobility experiment."
-					// << "m_curDriftBin: " << m_curDriftBin
 					// << "m_curDriftTime:" << m_curDriftTime;
 
 					mp_massSpecDataSet->insertDtHash(m_curDriftTime, mp_newSpectrum);
@@ -1937,7 +1894,7 @@ namespace msXpSmineXpert
 						// first drift cycle run).
 
 						bool sqlResult = sqlite3Handler.writeDbDriftData(database,
-								m_curDriftTime, m_curDriftBin, &m_driftDataId);
+								m_curDriftTime, &m_driftDataId);
 
 						if(!sqlResult || m_driftDataId == -1)
 						{
