@@ -402,30 +402,6 @@ namespace msXpSmineXpert
 		//! Stores the previous mass spectrum's drift time.
 		double m_prevDriftTime = -1;
 
-		//! Drift time bin associated with the mass spectrum currently being loaded.
-		/*!
-
-			This value is deduced by analyzing the cycling of mass spectra in the
-			drift cycles.
-
-*/
-		int m_curDriftBin = 0;
-
-		//! Number of drift bins in a drift cycle.
-		/*!
-
-			This value is deduced by analyzing the cycling of mass spectra in the
-			drift cycles.
-
-*/
-		int m_driftBinCount = -1;
-
-		//! Number of scan windows for the currently loaded mass spectrum.
-		/*!
-
-			At the present time, only the first scan window is accounted for.
-
-*/
 		int m_scanWindowListCount = -1;
 
 		//! Scan window lower limit, that is m/z range left border.
