@@ -78,7 +78,10 @@ namespace msXpSmineXpert
 		m_mzShiftStdDev = other.m_mzShiftStdDev;
 
 		// This value is set along with the MASS_TOLERANCE_MZ value!
+		// Only account for values that are > 0.
+		m_nonZeroSmallestStep	= other.m_nonZeroSmallestStep;
 		m_smallestStep = other.m_smallestStep;
+		m_smallestStepMedian = other.m_smallestStepMedian;
 		m_smallestStepAvg = other.m_smallestStepAvg;
 		m_smallestStepStdDev = other.m_smallestStepStdDev;
 
@@ -136,7 +139,9 @@ namespace msXpSmineXpert
 			m_mzShiftStdDev = other.m_mzShiftStdDev;
 
 			// This value is set along with the MASS_TOLERANCE_MZ value!
+			m_nonZeroSmallestStep	= other.m_nonZeroSmallestStep;
 			m_smallestStep = other.m_smallestStep;
+			m_smallestStepMedian = other.m_smallestStepMedian;
 			m_smallestStepAvg = other.m_smallestStepAvg;
 			m_smallestStepStdDev = other.m_smallestStepStdDev;
 
@@ -195,7 +200,9 @@ namespace msXpSmineXpert
 			m_mzShiftAvg = 0;
 			m_mzShiftStdDev = 0;
 
+			m_nonZeroSmallestStep =  std::numeric_limits<double>::max();
 			m_smallestStep =  std::numeric_limits<double>::max();
+			m_smallestStepMedian = 0;
 			m_smallestStepAvg = 0;
 			m_smallestStepStdDev = 0;
 
@@ -347,13 +354,18 @@ namespace msXpSmineXpert
 			double average;
 			double variance;
 			double stdDeviation;
+			double nonZeroSmallest;
 			double smallest;
+			double smallestMedian;
 			double greatest;
 
 			msXpS::doubleListStatistics(binList, &sum, &variance, &average,
-					&stdDeviation, &smallest, &greatest);
+					&stdDeviation, &nonZeroSmallest, &smallest, &smallestMedian, &greatest);
 
 			// The smallest step
+			if(nonZeroSmallest < m_nonZeroSmallestStep)
+				m_nonZeroSmallestStep = nonZeroSmallest;
+
 			m_smallestStepList.append(smallest);
 			if(smallest < m_smallestStep)
 				m_smallestStep = smallest;
@@ -379,12 +391,15 @@ namespace msXpSmineXpert
 			double average;
 			double variance;
 			double stdDeviation;
+			double nonZeroSmallest;
 			double smallest;
+			double smallestMedian;
 			double greatest;
 
 			// The spectrum size.
 			msXpS::doubleListStatistics(m_spectrumSizeList, &sum, &average,
-					&variance, &stdDeviation, &smallest, &greatest);
+					&variance, &stdDeviation,
+					&nonZeroSmallest, &smallest, &smallestMedian, &greatest);
 			m_spectrumSizeAvg = average;
 			m_spectrumSizeStdDev = stdDeviation;
 
@@ -411,31 +426,41 @@ namespace msXpSmineXpert
 
 			// The first mz value
 			msXpS::doubleListStatistics(m_firstMzList, &sum, &average,
-					&variance, &stdDeviation, &smallest, &greatest);
+					&variance, &stdDeviation,
+					&nonZeroSmallest, &smallest, &smallestMedian, &greatest);
 			m_firstMzAvg = average;
 			m_firstMzStdDev = stdDeviation;
 
 			// The last mz value
 			msXpS::doubleListStatistics(m_lastMzList, &sum, &average,
-					&variance, &stdDeviation, &smallest, &greatest);
+					&variance, &stdDeviation,
+					&nonZeroSmallest, &smallest, &smallestMedian, &greatest);
 			m_lastMzAvg = average;
 			m_lastMzStdDev = stdDeviation;
 
 			// The mz shift
 			msXpS::doubleListStatistics(m_mzShiftList, &sum, &average,
-					&variance, &stdDeviation, &smallest, &greatest);
+					&variance, &stdDeviation,
+					&nonZeroSmallest, &smallest, &smallestMedian, &greatest);
 			m_mzShiftAvg = average;
 			m_mzShiftStdDev = stdDeviation;
 
 			// The smallest step
 			msXpS::doubleListStatistics(m_smallestStepList, &sum, &average,
-					&variance, &stdDeviation, &smallest, &greatest);
+					&variance, &stdDeviation,
+					&nonZeroSmallest, &smallest, &smallestMedian, &greatest);
+			m_smallestStepMedian = smallestMedian;
+
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+				//<< "m_smallestStepMedian:" << m_smallestStepMedian;
+
 			m_smallestStepAvg = average;
 			m_smallestStepStdDev = stdDeviation;
 
 			// The greatest step
 			msXpS::doubleListStatistics(m_greatestStepList, &sum, &average,
-					&variance, &stdDeviation, &smallest, &greatest);
+					&variance, &stdDeviation,
+					&nonZeroSmallest, &smallest, &smallestMedian, &greatest);
 			m_greatestStepAvg = average;
 			m_greatestStepStdDev = stdDeviation;
 
@@ -548,7 +573,7 @@ namespace msXpSmineXpert
 						"\tTotal number of spectra: %d\n"
 						"\tAverage of spectrum size: %.6f\n"
 						"\tStdDev of spectrum size: %.6f\n"
-						"\tMininum m/z value: %.6f\n"
+						"\tMinimum m/z value: %.6f\n"
 						"\tAverage of first m/z value: %.6f\n"
 						"\tStdDev of first m/z value: %.6f\n"
 						"\tMaximum m/z value: %.6f\n"
@@ -558,31 +583,35 @@ namespace msXpSmineXpert
 						"\tMaximum m/z shift: %.6f\n"
 						"\tAverage of m/z shift: %.6f\n"
 						"\tStdDev of m/z shift: %.6f\n"
+						"\tSmallest non-zero Delta of m/z (step): %.6f\n"
 						"\tSmallest Delta of m/z (step): %.6f\n"
+						"\tMedian of smallest Delta of m/z (step): %.6f\n"
 						"\tAverage of smallest Delta of m/z (step): %.6f\n"
 						"\tStdDev of smallest Delta of m/z (step): %.6f\n"
 						"\tGreatest Delta of m/z (step): %.6f\n"
 						"\tAverage of greatest Delta of m/z (step): %.6f\n"
 						"\tStdDev of greatest Delta of m/z (step): %.6f\n",
-						m_spectrumCount,
-						m_spectrumSizeAvg,
-						m_spectrumSizeStdDev,
-						m_minMz,
-						m_firstMzAvg,
-						m_firstMzStdDev,
-						m_maxMz,
-						m_lastMzAvg,
-						m_lastMzStdDev,
-						m_smallestMzShift,
-						m_greatestMzShift,
-						m_mzShiftAvg,
-						m_mzShiftStdDev,
-						m_smallestStep,
-						m_smallestStepAvg,
-						m_smallestStepStdDev,
-						m_greatestStep,
-						m_greatestStepAvg,
-						m_greatestStepStdDev));
+				m_spectrumCount,
+				m_spectrumSizeAvg,
+				m_spectrumSizeStdDev,
+				m_minMz,
+				m_firstMzAvg,
+				m_firstMzStdDev,
+				m_maxMz,
+				m_lastMzAvg,
+				m_lastMzStdDev,
+				m_smallestMzShift,
+				m_greatestMzShift,
+				m_mzShiftAvg,
+				m_mzShiftStdDev,
+				m_nonZeroSmallestStep,
+				m_smallestStep,
+				m_smallestStepMedian,
+				m_smallestStepAvg,
+				m_smallestStepStdDev,
+				m_greatestStep,
+				m_greatestStepAvg,
+				m_greatestStepStdDev));
 
 			return text;
 		}
