@@ -109,11 +109,6 @@ namespace msXpSmineXpert
 					"drift time step", "driftTimeStep FLOAT");
 			m_metaDataTableSpecifs.appendTableFieldSpecif(sqlTableFieldSpecifs);
 
-			sqlTableFieldSpecifs = new SqlTableFieldSpecifs(
-					"metadata", "driftBinCount", FieldQtType::INT, FieldSqlType::INTEGER,
-					"number of drift time bins", "driftBinCount INTEGER");
-			m_metaDataTableSpecifs.appendTableFieldSpecif(sqlTableFieldSpecifs);
-
 			sqlTableFieldSpecifs = new SqlTableFieldSpecifs(
 					"metadata", "compressionType", FieldQtType::INT, FieldSqlType::INTEGER,
 					"compression type (1 for zlib)", "compressionType INTEGER");
@@ -355,10 +350,6 @@ namespace msXpSmineXpert
 					"drift time", "driftTime FLOAT UNIQUE");
 			m_driftDataTableSpecifs.appendTableFieldSpecif(sqlTableFieldSpecifs);
 
-			sqlTableFieldSpecifs = new SqlTableFieldSpecifs(
-					"driftData", "driftBin", FieldQtType::INT, FieldSqlType::INTEGER,
-					"drift bin", "driftBin INTEGER UNIQUE");
-			m_driftDataTableSpecifs.appendTableFieldSpecif(sqlTableFieldSpecifs);
 
 			return true;
 		}
@@ -371,8 +362,6 @@ namespace msXpSmineXpert
 
 		\param driftTime drift time value.
 
-		\param driftBin drift bin value.
-
 		\param recordId pointer to an int in which to store the id of the record
 		generated by this writing operation. Cannot be nullptr.
 
@@ -383,7 +372,7 @@ namespace msXpSmineXpert
 */
 	bool
 		MassSpecSqlite3Handler::writeDbDriftData(QSqlDatabase &database,
-				double driftTime, int driftBin, int *recordId)
+				double driftTime, int *recordId)
 		{
 			if(recordId == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
@@ -395,7 +384,7 @@ namespace msXpSmineXpert
 			// that it might happen that the mzML file contains
 
 			// driftTime values like 'nan' or 'inf' (not yet understood why).
-			// In these cases we set driftTime and driftBin to -1, so that
+			// In these cases we set driftTime, so that
 			// we can recognize these spectra later when working in the
 			// database.
 
@@ -409,19 +398,11 @@ namespace msXpSmineXpert
 						__FILE__, __LINE__, __FUNCTION__);
 			}
 
-			// else
-			//{
-			// qDebug() << __FILE__ << __LINE__
-			// << "driftTime to write is:" << driftTime;
-			//}
-
-
 			// Look if the table has already an identical record.
 
-			// qDebug() << __FILE__ << __LINE__
-			// << "writeDbDriftData: "
-			// << "driftTime: " << driftTime
-			// << "driftBin: " << driftBin;
+			 qDebug() << __FILE__ << __LINE__
+			 << "writeDbDriftData: "
+			 << "driftTime: " << driftTime;
 
 
 			QSqlQuery *sqlQuery = new QSqlQuery(database);
@@ -452,10 +433,9 @@ namespace msXpSmineXpert
 			{
 				// We need to create a new row in that driftData table:
 
-				sqlQuery->prepare("INSERT INTO driftData(driftTime,driftBin) "
-						"VALUES (:driftTime,:driftBin)");
+				sqlQuery->prepare("INSERT INTO driftData(driftTime) "
+						"VALUES (:driftTime)");
 				sqlQuery->bindValue(":driftTime", driftTime);
-				sqlQuery->bindValue(":driftBin", driftBin);
 
 				bool res = sqlQuery->exec();
 
@@ -465,9 +445,8 @@ namespace msXpSmineXpert
 					QString error = sqlError.text();
 
 					qDebug() << __FILE__ << __LINE__
-						<< "Failed to store the driftTime/driftBin record "
-						<< driftTime << "--" << driftBin << "in the "
-						<< "driftData table. Error:" << error;
+						<< "Failed to store the driftTime record "
+						<< driftTime << "in the driftData table. Error:" << error;
 
 					delete sqlQuery;
 
@@ -497,9 +476,8 @@ namespace msXpSmineXpert
 						QString error = sqlError.text();
 
 						qDebug() << __FILE__ << __LINE__
-							<< "Failed to store the driftTime/driftBin record "
-							<< driftTime << "--" << driftBin << "in the "
-							<< "driftData table. Error:" << error;
+							<< "Failed to store the driftTime record "
+							<< driftTime << "in the driftData table. Error:" << error;
 
 						delete sqlQuery;
 
@@ -1061,7 +1039,7 @@ namespace msXpSmineXpert
 			// from metadata";
 			// metaData_id|fileName|acquisitionDate|spectrumListCount|driftTimeMin|driftTimeMax|
 			// <follows>
-			// <followed> driftTimeStep|driftBinCount|compressionType
+			// <followed> driftTimeStep|compressionType
 			// 1|/media/disk/devel/dataForMzml/mzml/file.mzml|2015.11.30|1200|0.0|10.7959|0.0542505|200|0
 
 			QSqlRecord sqlRecord = sqlQuery.record();
@@ -1278,9 +1256,8 @@ namespace msXpSmineXpert
 	bool
 		MassSpecSqlite3Handler::isDriftExperiment(QSqlDatabase &database)
 		{
-			// By asking the database to tell us if it has a value for
-			// driftBinCount in the metaData table we'll know if this database is
-			// for a mobility drift time experiment.
+			// We can ask to know how many drift time values there are in the
+			// driftData table.
 
 			if(!initializeDbForRead(database, false /* readMetaData */))
 				return false;
@@ -1288,47 +1265,46 @@ namespace msXpSmineXpert
 			QSqlQuery sqlQuery(database);
 			bool ok = false;
 
-			QString queryString("SELECT driftBinCount from metaData");
+			QString queryString("SELECT COUNT(*), driftTime FROM driftData");
+
+			ok = sqlQuery.exec(queryString);
 
 			ok = sqlQuery.exec(queryString);
 
 			if(!ok)
 			{
-				QString msg =
-					QString("Failed to get proper data from the database. Error: %1. Exiting.\n")
-					.arg(sqlQuery.lastError().text());
-
-				qFatal("Fatal error at %s@%d -- %s: %s",
-						__FILE__, __LINE__, __FUNCTION__,
-						msg.toLatin1().data());
-			}
-
-			if(!sqlQuery.isActive())
-				qFatal("Fatal error at %s@%d -- %s(). "
-						"The query failed: it is not active."
-						"Program aborted.",
-						__FILE__, __LINE__, __FUNCTION__);
-
-
-			if(!sqlQuery.isSelect())
-				qFatal("Fatal error at %s@%d -- %s(). "
-						"The query failed: it is not a SELECT query."
-						"Program aborted.",
-						__FILE__, __LINE__, __FUNCTION__);
-
-			if(!sqlQuery.first())
-				qFatal("Fatal error at %s@%d -- %s(). "
-						"Failed to get proper data from the database. Error:%s."
+				qFatal("Fatal error at %s@%d -- %s(). Error: %s."
+						"Failed to get proper data from the database.\n."
 						"Program aborted.",
 						__FILE__, __LINE__, __FUNCTION__,
 						sqlQuery.lastError().text().toLatin1().data());
+			}
 
-			int count = sqlQuery.value(0).toInt(&ok);
+			if(!sqlQuery.isActive())
+			{
+				qFatal(
+						"Fatal error at %s@%d. The query is not active. Program aborted.",
+						__FILE__, __LINE__);
+			}
 
-			if(!count)
-				return false;
+			// Get the number of records that were retrieved, because we'll need this
+			// to provide feedback to the caller.
+			if(!sqlQuery.first())
+			{
+				qDebug() << __FILE__ << __LINE__
+					<< "Failed to get the number of records. Returning.";
+			}
 
-			return true;
+			int recordCount =
+				sqlQuery.value(sqlQuery.record().indexOf("COUNT(*)")).toInt();
+
+			//qDebug() << __FILE__ << __LINE__
+			//<< "The recordCount:" << recordCount;
+
+			// Now reset the query
+			sqlQuery.finish();
+
+			return recordCount;
 		}
 
 
@@ -1489,12 +1465,6 @@ namespace msXpSmineXpert
 					metaData.setDoubleItem("driftTimeStep",
 							srcSqlQuery->value(fieldNo).toDouble());
 
-				fieldNo = srcSqlQuery->record().indexOf("driftBinCount");
-
-				if(!srcSqlQuery->value(fieldNo).isNull())
-					metaData.setDoubleItem("driftBinCount",
-							srcSqlQuery->value(fieldNo).toDouble());
-
 				fieldNo = srcSqlQuery->record().indexOf("compressionType");
 
 				if(!srcSqlQuery->value(fieldNo).isNull())
@@ -1546,7 +1516,7 @@ namespace msXpSmineXpert
 			if(srcSqlQuery == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
-			QString srcDbQueryString = "SELECT driftTime, driftBin FROM driftData";
+			QString srcDbQueryString = "SELECT driftTime FROM driftData";
 
 			bool ok = srcSqlQuery->exec(srcDbQueryString);
 
@@ -1569,12 +1539,10 @@ namespace msXpSmineXpert
 			}
 
 			double driftTime;
-			int driftBin;
 
 			while(srcSqlQuery->next())
 			{
 				driftTime = srcSqlQuery->value(0).toDouble();
-				driftBin = srcSqlQuery->value(1).toInt();
 
 				// Now that we have the values, we can INSERT these in the destination
 				// database driftData table. Their order in the destination database
@@ -1583,7 +1551,7 @@ namespace msXpSmineXpert
 
 				int recordId;
 
-				if(!writeDbDriftData(dstDatabase, driftTime, driftBin, &recordId))
+				if(!writeDbDriftData(dstDatabase, driftTime, &recordId))
 					qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 			}
 
