@@ -21,7 +21,7 @@
 
 using std::cout;
 
-#define TEST_DATA_DIR "/home/rusconi/devel/msxpertsuite/development/tests/data"
+#define TEST_DATA_DIR "/home/rusconi/devel/msxpertsuite/tests/data"
 
 namespace msXpSmineXpert
 {
@@ -60,7 +60,7 @@ namespace msXpSmineXpert
 		MassSpecDataSet *massSpecDataSet =
 			new MassSpecDataSet(Q_NULLPTR, "NOT_SET", fileName, /* isStreamed */ false);
 
-		int res = loader.loadData(massSpecDataSet);
+		int res = loader.loadDataToMassSpecDataSet(massSpecDataSet);
 
 		REQUIRE(res == 4970);
 
